module SPI_slave(clk, SCK, MOSI, MISO, SSEL, LED);
	input clk;
	input SCK, SSEL, MOSI;
	output MISO;
	output [3:0] LED;
	
	reg LED;
	reg [3:0] SCKr;  
	reg [2:0] bitcnt;  // Bit Counter
	reg byte_received; // has Byte received? 
	wire SCK_risingedge;
	wire SCK_fallingedge;
	reg [7:0] byte_data_sent;
	reg [7:0] byte_data_received;
	
	
	always @(posedge clk) SCKr <= {SCKr[2:0], SCK};
	assign SCK_risingedge = (SCKr[3:1]==3'b011);  // now we can detect SCK rising edges
	assign SCK_fallingedge = (SCKr[3:1]==3'b110);  // and falling edges

	always @(posedge clk)
	begin
	  if(~SSEL)
		 bitcnt <= 3'b000;
	  else
	  if(SCK_risingedge)
	  begin
		 bitcnt <= bitcnt + 3'b001;
		 byte_data_received <= {byte_data_received[6:0], MOSI};
	  end
	end

	always @(posedge clk) byte_received <= SSEL && SCK_risingedge && (bitcnt==3'b111);
	always @(posedge clk)  if(byte_received) LED[3:0] <= byte_data_received[3:0];

	always @(posedge clk)
	if(SSEL)
	  if(SCK_fallingedge)
		 if(bitcnt==3'b000)
			byte_data_sent <= 8'b0101_1010	;  // char Z
		 else
			byte_data_sent <= {byte_data_sent[6:0], 1'b0};

	assign MISO = byte_data_sent[7];  // send MSB first

endmodule

